@@ -13,7 +13,7 @@ class PermissionFlagMiddleware:
         response = self.get_response(request)
         if not waffle.switch_is_active(self.switch_name):
             for path in whitelisted_paths:
-                if request.path in path:
+                if path in request.path:
                     return response
             raise ServiceUnavailable()
         return response
